@@ -1,7 +1,8 @@
 package HTML::FormFu::Constraint::Equal;
+use Moose;
+extends 'HTML::FormFu::Constraint';
 
-use strict;
-use base 'HTML::FormFu::Constraint::_others';
+with 'HTML::FormFu::Role::Constraint::Others';
 
 use HTML::FormFu::Util qw(
     DEBUG_CONSTRAINTS
@@ -36,7 +37,15 @@ sub process {
 
         my $ok = _values_eq( $value, $other_value );
 
-        if ( $self->not() ? $ok : !$ok ) {
+        if ( $self->not ) {
+            if ( $value eq $EMPTY_STR ) {
+                # no error if both values are empty and not(1) is set
+            }
+            elsif ($ok) {
+                push @failed, $name;
+            }
+        }
+        elsif (!$ok) {
             push @failed, $name;
         }
 
@@ -45,7 +54,10 @@ sub process {
 
     # special case for $self->not()
     # no errors if all values are empty
-    if ( $self->not() && all { !defined || $_ eq $EMPTY_STR } values %values ) {
+    if ( $self->not
+        && $value eq $EMPTY_STR
+        && all { !defined || $_ eq $EMPTY_STR } values %values )
+    {
         return;
     }
 
@@ -95,6 +107,8 @@ sub _localize_args {
     return $self->parent->label;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -105,13 +119,17 @@ HTML::FormFu::Constraint::Equal - Multi-field Equality Constraint
 
 =head1 SYNOPSIS
 
-    type: Equal
-    name: repeat_password
-    others: password
+    - type: Password
+      name: password
+      constraints:
+      - type: Equal
+        others: repeat_password
+    - type: Password
+      name: repeat_password
 
 =head1 DESCRIPTION
 
-All fields named in L</others> must have an equal value to the field this 
+All fields named in L<HTML::FormFu::Constraint::_others/others> must have an equal value to the field this 
 constraint is attached to.
 
 =head1 SEE ALSO
@@ -129,3 +147,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
