@@ -1,16 +1,17 @@
 package HTML::FormFu::Element::Reset;
+use Moose;
 
-use strict;
-use base 'HTML::FormFu::Element::Button';
-use Class::C3;
+extends 'HTML::FormFu::Element::Button';
 
-sub new {
-    my $self = shift->next::method(@_);
+after BUILD => sub {
+    my $self = shift;
 
     $self->field_type('reset');
 
-    return $self;
-}
+    return;
+};
+
+__PACKAGE__->meta->make_immutable;
 
 1;
 
@@ -38,7 +39,7 @@ L<HTML::FormFu::Element::_Input>,
 L<HTML::FormFu::Element::_Field>, 
 L<HTML::FormFu::Element>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -48,3 +49,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
