@@ -1,8 +1,7 @@
 package HTML::FormFu::Transformer;
 
-use strict;
-use base 'HTML::FormFu::Processor';
-use Class::C3;
+use Moose;
+extends 'HTML::FormFu::Processor';
 
 use HTML::FormFu::Exception::Transformer;
 use Scalar::Util qw( blessed );
@@ -18,7 +17,7 @@ sub process {
         my @return;
         for my $value (@$values) {
             my ($return) = eval { $self->transformer( $value, $params ) };
-            
+
             if ($@) {
                 push @errors, $self->return_error($@);
                 push @return, undef;
@@ -31,13 +30,15 @@ sub process {
     }
     else {
         ($return) = eval { $self->transformer( $values, $params ) };
-        
+
         if ($@) {
             push @errors, $self->return_error($@);
         }
     }
 
-    return ( $return, @errors );
+    $self->set_nested_hash_value( $params, $self->nested_name, $return );
+
+    return (@errors);
 }
 
 sub return_error {
@@ -50,6 +51,8 @@ sub return_error {
     return $err;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -66,6 +69,12 @@ HTML::FormFu::Transformer - Transformer Base Class
 
 =head1 CORE TRANSFORMERS
 
+=over
+
+=item L<HTML::FormFu::Transformer::Callback>
+
+=back
+
 =head1 AUTHOR
 
 Carl Franks, C<cfranks@cpan.org>
@@ -74,3 +83,5 @@ Carl Franks, C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
