@@ -1,9 +1,9 @@
 package HTML::FormFu::Validator::Callback;
 
-use strict;
-use base 'HTML::FormFu::Validator';
+use Moose;
+extends 'HTML::FormFu::Validator';
 
-__PACKAGE__->mk_accessors(qw/ callback /);
+has callback => ( is => 'rw', traits => ['Chained'] );
 
 sub validate_value {
     my ( $self, $value ) = @_;
@@ -17,6 +17,8 @@ sub validate_value {
     return $ok;
 }
 
+__PACKAGE__->meta->make_immutable;
+
 1;
 
 __END__
@@ -53,7 +55,7 @@ Arguments: "subroutine-name"
 
 Is a sub-class of, and inherits methods from L<HTML::FormFu::Validator>
 
-L<HTML::FormFu::FormFu>
+L<HTML::FormFu>
 
 =head1 AUTHOR
 
@@ -63,3 +65,5 @@ Carl Franks C<cfranks@cpan.org>
 
 This library is free software, you can redistribute it and/or modify it under
 the same terms as Perl itself.
+
+=cut
